MedianRank
==========

.. currentmodule:: pykeen.metrics.ranking

.. autoclass:: MedianRank
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~MedianRank.increasing
      ~MedianRank.name
      ~MedianRank.value_range

   .. rubric:: Methods Summary

   .. autosummary::

      ~MedianRank.__call__
      ~MedianRank.expected_value

   .. rubric:: Attributes Documentation

   .. autoattribute:: increasing
   .. autoattribute:: name
   .. autoattribute:: value_range

   .. rubric:: Methods Documentation

   .. automethod:: __call__
   .. automethod:: expected_value
